@@ -26,8 +26,9 @@ from neo4jrestclient.labels import NodeLabelsProxy, LabelsProxy
 from neo4jrestclient.query import (
     QuerySequence, FilterSequence, QueryTransaction, CypherException
 )
-from neo4jrestclient.request import (Request, NotFoundError, StatusException,
-                                     TransactionException)
+from neo4jrestclient.request import Request
+from neo4jrestclient.exceptions import (NotFoundError, StatusException,
+                                        TransactionException)
 from neo4jrestclient.traversals import TraversalDescription
 from neo4jrestclient.utils import (PY2, text_type, smart_quote, string_types,
                                    unquote)
@@ -1384,19 +1385,18 @@ class IndexesProxy(dict):
                                   "Error requesting indexes with GET %s"
                                   % self.url)
 
-    def create(self, name, **kwargs):
+    def create(self, name, **config):
+        tx = Transaction.get_transaction(config.pop("tx", None))
+        if not config:
+            config = {
+                'type': INDEX_FULLTEXT,
+                'provider': "lucene",
+            }
         data = {
             'name': name,
-            'config': {
-                'type': kwargs.get("type", INDEX_FULLTEXT),
-                'provider': kwargs.get("provider", "lucene"),
-            }
+            'config': config,
         }
-        tx = Transaction.get_transaction(kwargs.get("tx", None))
         if tx:
-            if "tx" in kwargs and isinstance(kwargs["tx"], Transaction):
-                x = kwargs.pop("tx", None)
-                del x  # Makes pyflakes happy
             url = "/%s/%s" % (INDEX, self._index_for)
             if self._index_for == NODE:
                 op = tx.append(TX_POST, url, data=data, obj=self,
