@@ -4,9 +4,8 @@
 from collections import Sequence
 
 from neo4jrestclient.constants import RAW
-from neo4jrestclient.request import (
-    Request, StatusException, TransactionException
-)
+from neo4jrestclient.request import Request
+from neo4jrestclient.exceptions import StatusException, TransactionException
 from neo4jrestclient.utils import text_type, string_types
 
 
@@ -154,8 +153,14 @@ class Q(BaseQ):
             match = self.match
         elif self.lookup in ["in", "inrange"]:
             lookup = u"IN"
-            match = u"['{0}']".format(u"', '".join([self._escape(m)
-                                      for m in self.match]))
+            matchs = []
+            for list_item in self.match:
+                if isinstance(list_item, string_types):
+                    item = self._escape(list_item)
+                else:
+                    item = list_item
+                matchs.append(item)
+            match = matchs
         elif self.lookup == "isnull":
             if self.match:
                 lookup = u"="
@@ -164,10 +169,16 @@ class Q(BaseQ):
             match = u"null"
         elif self.lookup in ["eq", "equals"]:
             lookup = u"="
-            match = u"'{0}'".format(self._escape(self.match))
+            if isinstance(self.match, string_types):
+                match = u"'{0}'".format(self._escape(self.match))
+            else:
+                match = self.match
         elif self.lookup in ["neq", "notequals"]:
             lookup = u"<>"
-            match = u"'{0}'".format(self._escape(self.match))
+            if isinstance(self.match, string_types):
+                match = u"'{0}'".format(self._escape(self.match))
+            else:
+                match = self.match
         else:
             lookup = self.lookup
             match = u""
@@ -582,9 +593,9 @@ class QueryTransaction(object):
                 self.finished = True
                 for reference in self.executed:
                     obj = reference["obj"]
-                    obj._elements = []
-                    obj.columns = None
-                    obj = None
+                    if obj is not None:
+                        obj._elements = []
+                        obj.columns = None
                 self.executed = []
             else:
                 raise TransactionException(response.status_code)
